# Lila CLI


## How to release

Required

* twine

First build the project:

```
python3.11 -m build
```

Then upload the package to PyPI:

```
twine upload dist/*
```

You will find the creds in Notion
